#!/bin/bash

createZarafaUser () {
	# $1 == username
	# $2 == role (contact, user, admin, store)
	local OPTIONS=$3

	udm-test users/user create \
		--position "cn=users,$ldap_base" \
		--set username="$1" \
		--set firstname="Firstname" \
		--set lastname="Lastname" \
		--set password="univention" \
		--set mailPrimaryAddress="$(random_mailaddress)@$domainname" \
		$OPTIONS \
		--set zarafa-role="$2"
	[ ! "$?" = "0" ] && fail_test 140 "cannot create user $1"
}

createZarafaContact () {
	# $1 == Firstname
	# $2 == Surname
	local OPTIONS=$3

	udm-test zarafa/contact create \
		--position "cn=contacts,cn=zarafa,$ldap_base" \
		--set firstname="$1" \
		--set lastname="$2" \
		--set e-mail="$(random_mailaddress)@someother.domain" \
		$OPTIONS 
	[ ! "$?" = "0" ] && fail_test 140 "cannot create contact $1 $2"
}

deleteZarafaContact () {
	# $1 == cn
	udm-test zarafa/contact delete \
		--dn "cn=${1},cn=contacts,cn=zarafa,$ldap_base"
	[ ! "$?" = "0" ] && fail_test 140 "cannot delete contact ${1}"
}

createZarafaNonactive () {
	# $1 == username (mailboxname)
	# $2 == logindenied? 1=True 0=False
	local OPTIONS=$3
	# $4 == password 

	udm-test zarafa/non-active create \
		--position "cn=non-active,cn=zarafa,$ldap_base" \
		--set username="$1" \
		--set logindenied="$2" \
		--set firstname="Firstname" \
		--set lastname="Lastname" \
		--set password="$4" \
		--set mailPrimaryAddress="$(random_mailaddress)@$domainname" \
		$OPTIONS 
	[ ! "$?" = "0" ] && fail_test 140 "cannot create non-active user $1"
}

deleteZarafaNonactive () {
	# $1 == cn
	udm-test zarafa/non-active delete \
		--dn "uid=$1,cn=non-active,cn=zarafa,$ldap_base"
	[ ! "$?" = "0" ] && fail_test 140 "cannot delete non-active user $1"
}

get_total_zarafa_user_count () 
{
	zarafa-admin --user-count | grep Total | awk '{print $2}'
}

get_active_zarafa_user_count () 
{
	zarafa-admin --user-count | grep Active | awk '{print $4}'
}

get_nonactive_zarafa_user_count () 
{
	zarafa-admin --user-count | grep Non-active | awk '{print $4}'
}

wait_until_user_is_in_zarafa ()
{
	local USERNAME=$1
	local TIMEOUT=120

	for((i=0;i<$TIMEOUT;i++)); do
		zarafa-admin -l | egrep -q "$USERNAME" && break
		echo -n '.'
		sleep 1
	done

	test $i = $TIMEOUT && return 1 || return 0
}

wait_until_user_is_removed_in_zarafa ()
{
	local USERNAME=$1
	local TIMEOUT=120

	for((i=0;i<$TIMEOUT;i++)); do
		zarafa-admin -l | egrep -q "$USERNAME" || break
		echo -n '.'
		sleep 1
	done

	test $i = $TIMEOUT && return 1 || return 0
}

zarafa_login ()
{
	username="$1"
	password="$2"

	echo -n "Testing login ($username:$password): "

	eval "$(ucr shell hostname domainname)"

	result=$(curl -X POST --data "username=$username&password=$password" "http://$hostname.$domainname/webapp/zarafa.php?service=authenticate" | grep "\"authenticated\":true")

	if [ 0 -ne $? ]; then
		echo "Connection failed"
		return 1
	fi

	if [ -n "$result" ]; then
  		echo "Login passed"
		return 0
	else
  		echo "Login failed"
		return 1
	fi

}
